@@ -74,15 +74,6 @@ class GitConfig:
             self.release = GitReleaseConfig()
 
 
-@dataclass
-class PyPIConfig:
-    """PyPI configuration."""
-    publish: bool = True
-    repository: str = "pypi"
-    token_env_var: str = "PYPI_TOKEN"  # Default to PYPI_TOKEN for backward compatibility
-    uv_token_env_var: str = "UV_PUBLISH_TOKEN"  # UV-specific token env var
-
-
 @dataclass
 class DockerConfig:
     """Docker configuration."""
@@ -116,125 +107,64 @@ class GitHubConfig:
 
 @dataclass
 class Config:
-    """Main configuration."""
+    """Main configuration class."""
     version: VersionConfig
     changelog: ChangelogConfig
     git: GitConfig
-    pypi: PyPIConfig
     testing: TestingConfig
     github: GitHubConfig
 
-    @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> 'Config':
-        """Create config from dictionary.
-        
-        Args:
-            data: Configuration dictionary
-        
-        Returns:
-            Config object
-        
-        Raises:
-            ReleaseError: If configuration is invalid
-        """
-        try:
-            version = VersionConfig(**data.get("version", {}))
-            
-            ai_config = AIConfig(**data.get("changelog", {}).get("ai", {}))
-            changelog = ChangelogConfig(
-                ai=ai_config,
-                sections=data.get("changelog", {}).get("sections", []),
-                commit_conventions=data.get("changelog", {}).get("commit_conventions", {})
-            )
-            
-            git_release = GitReleaseConfig(**data.get("git", {}).get("release", {}))
-            git = GitConfig(
-                push=data.get("git", {}).get("push", True),
-                tag_prefix=data.get("git", {}).get("tag_prefix", "v"),
-                release=git_release
-            )
-            
-            pypi = PyPIConfig(**data.get("pypi", {}))
-            
-            docker = DockerConfig(**data.get("testing", {}).get("docker", {}))
-            testing = TestingConfig(
-                run_before_release=data.get("testing", {}).get("run_before_release", True),
-                docker=docker
-            )
-            
-            github = GitHubConfig(**data.get("github", {}))
-            
-            return cls(
-                version=version,
-                changelog=changelog,
-                git=git,
-                pypi=pypi,
-                testing=testing,
-                github=github
-            )
-        except (TypeError, ValueError) as e:
-            raise ReleaseError(
-                code=ErrorCode.CONFIG_INVALID,
-                message=f"Invalid configuration: {e}",
-                fix_instructions=[
-                    "Check your configuration against the template below:",
-                    "",
-                    DEFAULT_CONFIG
-                ]
-            )
 
-
-def load_config(path: str = ".") -> Config:
-    """Load configuration from file.
+def load_config(workspace_dir: Optional[Path] = None) -> Config:
+    """Load configuration from .release-master.yaml.
     
     Args:
-        path: Path to configuration file or directory
-    
+        workspace_dir: Optional workspace directory path
+        
     Returns:
         Config object
-    
+        
     Raises:
-        ReleaseError: If configuration file is not found or is invalid
+        ReleaseError: If config is invalid or missing
     """
-    config_path = Path(path)
-    if config_path.is_dir():
-        config_path = config_path / ".release-master.yaml"
+    workspace_dir = Path(workspace_dir or os.getcwd())
+    config_path = workspace_dir / ".release-master.yaml"
     
+    # Create default config if not exists
     if not config_path.exists():
-        raise ReleaseError(
-            code=ErrorCode.CONFIG_NOT_FOUND,
-            message=f"Configuration file not found: {config_path}",
-            fix_instructions=[
-                "Create a .release-master.yaml file in your project root with the following template:",
-                "",
-                DEFAULT_CONFIG
-            ]
-        )
+        with open(config_path, "w") as f:
+            yaml.safe_dump(DEFAULT_CONFIG, f)
     
     try:
         with open(config_path) as f:
             data = yaml.safe_load(f)
         
-        if not data:
-            raise ReleaseError(
-                code=ErrorCode.CONFIG_INVALID,
-                message="Configuration file is empty",
-                fix_instructions=[
-                    "Add configuration to your .release-master.yaml file using the template below:",
-                    "",
-                    DEFAULT_CONFIG
-                ]
-            )
+        # Load and validate sections
+        version = VersionConfig(**data.get("version", {}))
+        changelog = ChangelogConfig(
+            ai=AIConfig(**data.get("changelog", {}).get("ai", {})),
+            sections=data.get("changelog", {}).get("sections", []),
+            commit_conventions=data.get("changelog", {}).get("commit_conventions", {})
+        )
+        git = GitConfig(**data.get("git", {}))
+        testing = TestingConfig(**data.get("testing", {}))
+        github = GitHubConfig(**data.get("github", {}))
         
-        return Config.from_dict(data)
-    except yaml.YAMLError as e:
+        return Config(
+            version=version,
+            changelog=changelog,
+            git=git,
+            testing=testing,
+            github=github
+        )
+        
+    except Exception as e:
         raise ReleaseError(
             code=ErrorCode.CONFIG_INVALID,
-            message=f"Invalid YAML syntax in configuration file: {e}",
+            message=f"Failed to load config: {str(e)}",
             fix_instructions=[
-                "Fix the YAML syntax in your configuration file",
-                "Use the template below as a reference:",
-                "",
-                DEFAULT_CONFIG
-            ]
+                "Check your .release-master.yaml for syntax errors",
+                "Compare against the default configuration"
+            ],
+            cause=e
         ) 
\ No newline at end of file
